
"""Adds a network serviceProvider to a physical network"""
from baseCmd import *
from baseResponse import *
class addNetworkServiceProviderCmd (baseCmd):
    def __init__(self):
        self.isAsync = "true"
        """the name for the physical network service provider"""
        """Required"""
        self.name = None
        """the Physical Network ID to add the provider to"""
        """Required"""
        self.physicalnetworkid = None
        """the destination Physical Network ID to bridge to"""
        self.destinationphysicalnetworkid = None
        """"""
        self.id = None
        """"""
        self.id = None
        """the list of services to be enabled for this physical network service provider"""
        self.servicelist = []
        """"""
        self.starteventid = None
        self.required = ["name","physicalnetworkid",]

class addNetworkServiceProviderResponse (baseResponse):
    def __init__(self):
        """uuid of the network provider"""
        self.id = None
        """true if individual services can be enabled/disabled"""
        self.canenableindividualservice = None
        """the destination physical network"""
        self.destinationphysicalnetworkid = None
        """the provider name"""
        self.name = None
        """the physical network this belongs to"""
        self.physicalnetworkid = None
        """services for this provider"""
        self.servicelist = None
        """state of the network provider"""
        self.state = None

